@@ -1,4 +1,5 @@
 test_that("can highlight html file", {
+  skip_if_not_installed("xml2")
   # verify_output() seems to be generating the wrong line endings
   skip_on_os("windows")
 
@@ -8,16 +9,30 @@ test_that("can highlight html file", {
   })
 })
 
+test_that("highlight all pre inside div.downlit", {
+  skip_if_not_installed("xml2")
+  html <- xml2::read_xml(
+    "
+    <body>
+    <div class = 'downlit'>
+      <pre>1 + 2</pre>
+      <pre>3 + 4</pre>
+    </div>
+    <pre>No hightlight</pre>
+    </body>"
+  )
+  downlit_html_node(html)
+  expect_snapshot_output(show_xml(html))
+})
+
 test_that("special package string gets linked", {
-  # TODO: convert to snapshot tests
+  skip_if_not_installed("xml2")
   html <- xml2::read_xml("<p>before <code>{downlit}</code> after</p>")
   downlit_html_node(html)
-  expect_equal(length(xml2::xml_find_all(html, ".//a")), 1)
-  expect_equal(length(xml2::xml_find_all(html, ".//code")), 0)
+  expect_snapshot_output(show_xml(html))
 
   # But only when it's a real package
   html <- xml2::read_xml("<p>before <code>{notapkg}</code> after</p>")
   downlit_html_node(html)
-  expect_equal(length(xml2::xml_find_all(html, ".//a")), 0)
-  expect_equal(length(xml2::xml_find_all(html, ".//code")), 1)
+  expect_snapshot_output(show_xml(html))
 })
